==> openshift-model-config-6.3.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterConditionFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ClusterConditionFluent<A extends ClusterConditionFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildPromql instead.
   * @return The buildable object.
   */
  @Deprecated
  public PromQLClusterCondition getPromql();
  public PromQLClusterCondition buildPromql();
  public A withPromql(PromQLClusterCondition promql);
  public Boolean hasPromql();
  public A withNewPromql(String promql);
  public ClusterConditionFluent.PromqlNested<A> withNewPromql();
  public ClusterConditionFluent.PromqlNested<A> withNewPromqlLike(PromQLClusterCondition item);
  public ClusterConditionFluent.PromqlNested<A> editPromql();
  public ClusterConditionFluent.PromqlNested<A> editOrNewPromql();
  public ClusterConditionFluent.PromqlNested<A> editOrNewPromqlLike(PromQLClusterCondition item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PromqlNested<N> extends Nested<N>,PromQLClusterConditionFluent<ClusterConditionFluent.PromqlNested<N>>{
    public N and();
    public N endPromql();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterConditionFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterConditionFluent<A extends ClusterConditionFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildPromql instead.
   * @return The buildable object.
   */
  @Deprecated
  public PromQLClusterCondition getPromql();
  public PromQLClusterCondition buildPromql();
  public A withPromql(PromQLClusterCondition promql);
  public Boolean hasPromql();
  public A withNewPromql(String promql);
  public ClusterConditionFluent.PromqlNested<A> withNewPromql();
  public ClusterConditionFluent.PromqlNested<A> withNewPromqlLike(PromQLClusterCondition item);
  public ClusterConditionFluent.PromqlNested<A> editPromql();
  public ClusterConditionFluent.PromqlNested<A> editOrNewPromql();
  public ClusterConditionFluent.PromqlNested<A> editOrNewPromqlLike(PromQLClusterCondition item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PromqlNested<N> extends Nested<N>,PromQLClusterConditionFluent<ClusterConditionFluent.PromqlNested<N>>{
    public N and();
    public N endPromql();
    
  }
  
}
